==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ALengthofUnop.h <==
// public final class soot.jimple.parser.node.ALengthofUnop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 58c3437f677a880c soot_jimple_parser_node_ALengthofUnop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 33b1f5b96729d67a soot_jimple_parser_node_PUnop

// header file dependencies
// @dep_header soot_jimple_parser_node_PUnop

#include "soot/jimple/parser/node/PUnop.h"

#ifndef _JC_soot_jimple_parser_node_ALengthofUnop_H_
#define _JC_soot_jimple_parser_node_ALengthofUnop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TLengthof$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALengthofUnop$sub_refs	_jc_soot_jimple_parser_node_ALengthofUnop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALengthofUnop$sub_nonrefs	_jc_soot_jimple_parser_node_ALengthofUnop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALengthofUnop$refs	_jc_soot_jimple_parser_node_ALengthofUnop$refs;
typedef struct _jc_soot_jimple_parser_node_ALengthofUnop$nonrefs	_jc_soot_jimple_parser_node_ALengthofUnop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALengthofUnop$object	_jc_soot_jimple_parser_node_ALengthofUnop$object;

typedef const struct _jc_soot_jimple_parser_node_ALengthofUnop$vmethods	_jc_soot_jimple_parser_node_ALengthofUnop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALengthofUnop$vtable	_jc_soot_jimple_parser_node_ALengthofUnop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALengthofUnop$vtype	_jc_soot_jimple_parser_node_ALengthofUnop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALengthofUnop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *);
extern void _jc_soot_jimple_parser_node_ALengthofUnop$method$_init$7ebdee24d1a84f54(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_soot_jimple_parser_node_TLengthof$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ALengthofUnop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALengthofUnop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *);
extern struct _jc_soot_jimple_parser_node_TLengthof$object *_jc_soot_jimple_parser_node_ALengthofUnop$method$getLengthof$e1f91ab677291d98(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *);
extern void _jc_soot_jimple_parser_node_ALengthofUnop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ALengthofUnop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ALengthofUnop$method$setLengthof$22005f61e782e78a(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_soot_jimple_parser_node_TLengthof$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ALengthofUnop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALengthofUnop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ALengthofUnop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ALengthofUnop$method_info$getLengthof$e1f91ab677291d98;
extern _jc_method _jc_soot_jimple_parser_node_ALengthofUnop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ALengthofUnop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ALengthofUnop$method_info$setLengthof$22005f61e782e78a;
extern _jc_method _jc_soot_jimple_parser_node_ALengthofUnop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALengthofUnop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *);
	struct _jc_soot_jimple_parser_node_TLengthof$object	*(*getLengthof$e1f91ab677291d98)(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setLengthof$22005f61e782e78a)(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_soot_jimple_parser_node_TLengthof$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ALengthofUnop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PUnop$vmethods	soot_jimple_parser_node_PUnop;
	_jc_soot_jimple_parser_node_ALengthofUnop$vmethods	soot_jimple_parser_node_ALengthofUnop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALengthofUnop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALengthofUnop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALengthofUnop$sub_refs {
	struct _jc_soot_jimple_parser_node_TLengthof$object	*__5flengthof__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALengthofUnop$refs {
    _jc_soot_jimple_parser_node_ALengthofUnop$sub_refs	soot_jimple_parser_node_ALengthofUnop;
    _jc_soot_jimple_parser_node_PUnop$sub_refs	soot_jimple_parser_node_PUnop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALengthofUnop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALengthofUnop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PUnop$sub_nonrefs	soot_jimple_parser_node_PUnop;
    _jc_soot_jimple_parser_node_ALengthofUnop$sub_nonrefs	soot_jimple_parser_node_ALengthofUnop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALengthofUnop$object {
	_jc_soot_jimple_parser_node_ALengthofUnop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALengthofUnop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALengthofUnop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALengthofUnop$vtype _jc_soot_jimple_parser_node_ALengthofUnop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALengthofUnop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALengthofUnop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALengthofUnop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ALengthofUnop.h <==
// public final class soot.jimple.parser.node.ALengthofUnop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 58c3437f677a880c soot_jimple_parser_node_ALengthofUnop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 33b1f5b96729d67a soot_jimple_parser_node_PUnop

// header file dependencies
// @dep_header soot_jimple_parser_node_PUnop

#include "soot/jimple/parser/node/PUnop.h"

#ifndef _JC_soot_jimple_parser_node_ALengthofUnop_H_
#define _JC_soot_jimple_parser_node_ALengthofUnop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TLengthof$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALengthofUnop$sub_refs	_jc_soot_jimple_parser_node_ALengthofUnop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALengthofUnop$sub_nonrefs	_jc_soot_jimple_parser_node_ALengthofUnop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALengthofUnop$refs	_jc_soot_jimple_parser_node_ALengthofUnop$refs;
typedef struct _jc_soot_jimple_parser_node_ALengthofUnop$nonrefs	_jc_soot_jimple_parser_node_ALengthofUnop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALengthofUnop$object	_jc_soot_jimple_parser_node_ALengthofUnop$object;

typedef const struct _jc_soot_jimple_parser_node_ALengthofUnop$vmethods	_jc_soot_jimple_parser_node_ALengthofUnop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALengthofUnop$vtable	_jc_soot_jimple_parser_node_ALengthofUnop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALengthofUnop$vtype	_jc_soot_jimple_parser_node_ALengthofUnop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALengthofUnop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALengthofUnop$method$_init$7ebdee24d1a84f54(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_soot_jimple_parser_node_TLengthof$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ALengthofUnop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALengthofUnop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TLengthof$object *_jc_soot_jimple_parser_node_ALengthofUnop$method$getLengthof$e1f91ab677291d98(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALengthofUnop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALengthofUnop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALengthofUnop$method$setLengthof$22005f61e782e78a(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_soot_jimple_parser_node_TLengthof$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ALengthofUnop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALengthofUnop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ALengthofUnop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ALengthofUnop$method_info$getLengthof$e1f91ab677291d98;
extern _jc_method _jc_soot_jimple_parser_node_ALengthofUnop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ALengthofUnop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ALengthofUnop$method_info$setLengthof$22005f61e782e78a;
extern _jc_method _jc_soot_jimple_parser_node_ALengthofUnop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALengthofUnop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TLengthof$object	*(*getLengthof$e1f91ab677291d98)(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setLengthof$22005f61e782e78a)(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *, struct _jc_soot_jimple_parser_node_TLengthof$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ALengthofUnop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ALengthofUnop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PUnop$vmethods	soot_jimple_parser_node_PUnop;
	_jc_soot_jimple_parser_node_ALengthofUnop$vmethods	soot_jimple_parser_node_ALengthofUnop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALengthofUnop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALengthofUnop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALengthofUnop$sub_refs {
	struct _jc_soot_jimple_parser_node_TLengthof$object	*__5flengthof__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALengthofUnop$refs {
    _jc_soot_jimple_parser_node_ALengthofUnop$sub_refs	soot_jimple_parser_node_ALengthofUnop;
    _jc_soot_jimple_parser_node_PUnop$sub_refs	soot_jimple_parser_node_PUnop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALengthofUnop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALengthofUnop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PUnop$sub_nonrefs	soot_jimple_parser_node_PUnop;
    _jc_soot_jimple_parser_node_ALengthofUnop$sub_nonrefs	soot_jimple_parser_node_ALengthofUnop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALengthofUnop$object {
	_jc_soot_jimple_parser_node_ALengthofUnop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALengthofUnop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALengthofUnop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALengthofUnop$vtype _jc_soot_jimple_parser_node_ALengthofUnop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALengthofUnop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALengthofUnop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALengthofUnop_H_ */
